/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import echart from 'echarts'
(function (root, factory) {
  // eslint-disable-next-line
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    // eslint-disable-next-line
    define(['exports', 'echarts'], factory);
  } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
    // CommonJS
    factory(exports, require('echarts'));
  } else {
    // Browser globals
    factory({}, root.echarts);
  }
}(this, function (exports, echarts) {
  var log = function (msg) {
    if (typeof console !== 'undefined') {
      console && console.error && console.error(msg);
    }
  }
  if (!echarts) {
    echarts = echart
    // log('ECharts is not Loaded');
    // return;
  }
  if (!echarts.registerMap) {
    log('ECharts Map is not loaded')
    return;
  }
  echarts.registerMap('福州市', {
    "type": "FeatureCollection",
    "features": [{
      "type": "Feature",
      "properties": {
        "adcode": 440311,
        "name": "福州大学",
        "center": [113.935895, 22.748816],
        "centroid": [113.931239, 22.763198],
        "childrenNum": 0,
        "level": "district",
        "acroutes": [100000, 440000, 440300],
        "parent": {
          "adcode": 440300
        }
      },
      "geometry": {
        "type": "MultiPolygon",
        "coordinates": [
          [
            [
              [113.910959, 22.829995],
              [113.910146, 22.829729],
              [113.909235, 22.829601],
              [113.908944, 22.829658],
              [113.907474, 22.82962],
              [113.906284, 22.829213],
              [113.905993, 22.828928],
              [113.9052, 22.828462],
              [113.904846, 22.828385],
              [113.90432, 22.828454],
              [113.903859, 22.828226],
              [113.903044, 22.828205],
              [113.901884, 22.82873],
              [113.901692, 22.828977],
              [113.901026, 22.828928],
              [113.900564, 22.8287],
              [113.899491, 22.828304],
              [113.899362, 22.828167],
              [113.898299, 22.827859],
              [113.897314, 22.826832],
              [113.897666, 22.826009],
              [113.897183, 22.825198],
              [113.896831, 22.824873],
              [113.896208, 22.823923],
              [113.89609, 22.823567],
              [113.896046, 22.822836],
              [113.895715, 22.822617],
              [113.895607, 22.821926],
              [113.895146, 22.821431],
              [113.895274, 22.820915],
              [113.895264, 22.820382],
              [113.895563, 22.820016],
              [113.89535, 22.819345],
              [113.894856, 22.819088],
              [113.89404, 22.819424],
              [113.894373, 22.819878],
              [113.894158, 22.820165],
              [113.894201, 22.82048],
              [113.893397, 22.819502],
              [113.892775, 22.819107],
              [113.891079, 22.820601],
              [113.891573, 22.821233],
              [113.892754, 22.821767],
              [113.89272, 22.822014],
              [113.891283, 22.821716],
              [113.891015, 22.822063],
              [113.890478, 22.822094],
              [113.890811, 22.821787],
              [113.890853, 22.821528],
              [113.890296, 22.820915],
              [113.890307, 22.820718],
              [113.890661, 22.82063],
              [113.89095, 22.820333],
              [113.890779, 22.820056],
              [113.890199, 22.819847],
              [113.889352, 22.82239],
              [113.889223, 22.821757],
              [113.889535, 22.821609],
              [113.889212, 22.821155],
              [113.889352, 22.820789],
              [113.88902, 22.820173],
              [113.889514, 22.819947],
              [113.889503, 22.819512],
              [113.889234, 22.819345],
              [113.888331, 22.819581],
              [113.888257, 22.818019],
              [113.888934, 22.816898],
              [113.887046, 22.814293],
              [113.886922, 22.813537],
              [113.886128, 22.812607],
              [113.885565, 22.812236],
              [113.885465, 22.811916],
              [113.884966, 22.811543],
              [113.884899, 22.81099],
              [113.88462, 22.81099],
              [113.884879, 22.809941],
              [113.88462, 22.808913],
              [113.883768, 22.806402],
              [113.883559, 22.806178],
              [113.883512, 22.80331],
              [113.882563, 22.800981],
              [113.881898, 22.800383],
              [113.881962, 22.800042],
              [113.88178, 22.800007],
              [113.881801, 22.799616],
              [113.881717, 22.798561],
              [113.881873, 22.798174],
              [113.881717, 22.797685],
              [113.881374, 22.797717],
              [113.880387, 22.797598],
              [113.8794, 22.797125],
              [113.877169, 22.795344],
              [113.872748, 22.793328],
              [113.86589, 22.790279],
              [113.864248, 22.790398],
              [113.863797, 22.79007],
              [113.863401, 22.789469],
              [113.862842, 22.789507],
              [113.862197, 22.788646],
              [113.861187, 22.788609],
              [113.861134, 22.788708],
              [113.860256, 22.788658],
              [113.859987, 22.788768],
              [113.859095, 22.78853],
              [113.857808, 22.788014],
              [113.858259, 22.787194],
              [113.858956, 22.787163],
              [113.859033, 22.784869],
              [113.858966, 22.783623],
              [113.859183, 22.783169],
              [113.859481, 22.781873],
              [113.860468, 22.779726],
              [113.860812, 22.779104],
              [113.860523, 22.778856],
              [113.860672, 22.778617],
              [113.861027, 22.778738],
              [113.861337, 22.778272],
              [113.862551, 22.77865],
              [113.862657, 22.778559],
              [113.86223, 22.778094],
              [113.86151, 22.7776],
              [113.860821, 22.77661],
              [113.860597, 22.775622],
              [113.860609, 22.775067],
              [113.860105, 22.774079],
              [113.860329, 22.773753],
              [113.860501, 22.772972],
              [113.861467, 22.772725],
              [113.863708, 22.772696],
              [113.863935, 22.77228],
              [113.863709, 22.771655],
              [113.863302, 22.771707],
              [113.863248, 22.771469],
              [113.863687, 22.771004],
              [113.863656, 22.770637],
              [113.863967, 22.770193],
              [113.864547, 22.769837],
              [113.865148, 22.769906],
              [113.865234, 22.770421],
              [113.865726, 22.769936],
              [113.865728, 22.76958],
              [113.865888, 22.768995],
              [113.86577, 22.768748],
              [113.866253, 22.768451],
              [113.866586, 22.768372],
              [113.868173, 22.768177],
              [113.868733, 22.765784],
              [113.869139, 22.765287],
              [113.869761, 22.765199],
              [113.869708, 22.764814],
              [113.869794, 22.764217],
              [113.871767, 22.763272],
              [113.872272, 22.763142],
              [113.872604, 22.762875],
              [113.873452, 22.762538],
              [113.873367, 22.76234],
              [113.874162, 22.762094],
              [113.873635, 22.761083],
              [113.872949, 22.761321],
              [113.872828, 22.760738],
              [113.873013, 22.760717],
              [113.874247, 22.759937],
              [113.875299, 22.759205],
              [113.875694, 22.75872],
              [113.876702, 22.758046],
              [113.877048, 22.757245],
              [113.877411, 22.756741],
              [113.878215, 22.756061],
              [113.878495, 22.755605],
              [113.878044, 22.755714],
              [113.877229, 22.753706],
              [113.877617, 22.753647],
              [113.877035, 22.751163],
              [113.87783, 22.751007],
              [113.877938, 22.750751],
              [113.878837, 22.750059],
              [113.879471, 22.749662],
              [113.879267, 22.749024],
              [113.879107, 22.748908],
              [113.879814, 22.748382],
              [113.879406, 22.74727],
              [113.879991, 22.747216],
              [113.880431, 22.747022],
              [113.880857, 22.746334],
              [113.881376, 22.745994],
              [113.881391, 22.745424],
              [113.880904, 22.744789],
              [113.881026, 22.744467],
              [113.881556, 22.744004],
              [113.88182, 22.743334],
              [113.881835, 22.743018],
              [113.88205, 22.742756],
              [113.882619, 22.742474],
              [113.883031, 22.742068],
              [113.883659, 22.741037],
              [113.884028, 22.740245],
              [113.883241, 22.73881],
              [113.882496, 22.738038],
              [113.882393, 22.737319],
              [113.882141, 22.736939],
              [113.882029, 22.73629],
              [113.881632, 22.735786],
              [113.881948, 22.735073],
              [113.882307, 22.734781],
              [113.882571, 22.734191],
              [113.882356, 22.733759],
              [113.88206, 22.733618],
              [113.88147, 22.732974],
              [113.881219, 22.732361],
              [113.880984, 22.732068],
              [113.880457, 22.731958],
              [113.879798, 22.731108],
              [113.879562, 22.731018],
              [113.878852, 22.731177],
              [113.878178, 22.731049],
              [113.877817, 22.730344],
              [113.87772, 22.729869],
              [113.877505, 22.729651],
              [113.877431, 22.729117],
              [113.877064, 22.728256],
              [113.877182, 22.727672],
              [113.877537, 22.727444],
              [113.877515, 22.727118],
              [113.877859, 22.726455],
              [113.878309, 22.726277],
              [113.878652, 22.726009],
              [113.878814, 22.72503],
              [113.87877, 22.724447],
              [113.878384, 22.72395],
              [113.878344, 22.723534],
              [113.878171, 22.723195],
              [113.878557, 22.722444],
              [113.878837, 22.722128],
              [113.879234, 22.721258],
              [113.879727, 22.720444],
              [113.880531, 22.719724],
              [113.881744, 22.719139],
              [113.88198, 22.718398],
              [113.882313, 22.717792],
              [113.882044, 22.717229],
              [113.882065, 22.716723],
              [113.881903, 22.715507],
              [113.879865, 22.714793],
              [113.878462, 22.714782],
              [113.878106, 22.71486],
              [113.87638, 22.714276],
              [113.875037, 22.713368],
              [113.874973, 22.712565],
              [113.875026, 22.712268],
              [113.875381, 22.711802],
              [113.875617, 22.711753],
              [113.876142, 22.711387],
              [113.87684, 22.71117],
              [113.876734, 22.710874],
              [113.876218, 22.709971],
              [113.875714, 22.709299],
              [113.874887, 22.708714],
              [113.874565, 22.708189],
              [113.874179, 22.707842],
              [113.874748, 22.706427],
              [113.875853, 22.704457],
              [113.876056, 22.704409],
              [113.876593, 22.704675],
              [113.876925, 22.703437],
              [113.876925, 22.703081],
              [113.877258, 22.702982],
              [113.8773, 22.702595],
              [113.877956, 22.702259],
              [113.878717, 22.7022],
              [113.879962, 22.702468],
              [113.88067, 22.702397],
              [113.881002, 22.701685],
              [113.880627, 22.701219],
              [113.880456, 22.700765],
              [113.879833, 22.700873],
              [113.878836, 22.700765],
              [113.878633, 22.700685],
              [113.878095, 22.700863],
              [113.877912, 22.701229],
              [113.877397, 22.70125],
              [113.877699, 22.699418],
              [113.878009, 22.698884],
              [113.878802, 22.698369],
              [113.878954, 22.698093],
              [113.879072, 22.697488],
              [113.879372, 22.697093],
              [113.879726, 22.69621],
              [113.879521, 22.695696],
              [113.879082, 22.695409],
              [113.878256, 22.69509],
              [113.878009, 22.695072],
              [113.877655, 22.694825],
              [113.877365, 22.694388],
              [113.876174, 22.694031],
              [113.875885, 22.693824],
              [113.875349, 22.692775],
              [113.875187, 22.692687],
              [113.874984, 22.692191],
              [113.874522, 22.692053],
              [113.874297, 22.691696],
              [113.875747, 22.69058],
              [113.876133, 22.690063],
              [113.87669, 22.68963],
              [113.87742, 22.689787],
              [113.878021, 22.688875],
              [113.878708, 22.688203],
              [113.879352, 22.687688],
              [113.879437, 22.686737],
              [113.879745, 22.685821],
              [113.879874, 22.686216],
              [113.880733, 22.686771],
              [113.881312, 22.687424],
              [113.882127, 22.687543],
              [113.882471, 22.688196],
              [113.882901, 22.688474],
              [113.883673, 22.689938],
              [113.889874, 22.689007],
              [113.891118, 22.688018],
              [113.892814, 22.688196],
              [113.893974, 22.688552],
              [113.894746, 22.689225],
              [113.897598, 22.691362],
              [113.89819, 22.692303],
              [113.897739, 22.692818],
              [113.896946, 22.694105],
              [113.89877, 22.693738],
              [113.899553, 22.69251],
              [113.899768, 22.69258],
              [113.899918, 22.692205],
              [113.900304, 22.692075],
              [113.901559, 22.692046],
              [113.902557, 22.691531],
              [113.903211, 22.691303],
              [113.904048, 22.690818],
              [113.904552, 22.690778],
              [113.905206, 22.690897],
              [113.905067, 22.691352],
              [113.905174, 22.691659],
              [113.905142, 22.692155],
              [113.904927, 22.692519],
              [113.90408, 22.692927],
              [113.90393, 22.694074],
              [113.903694, 22.694302],
              [113.903908, 22.695025],
              [113.903715, 22.695431],
              [113.903233, 22.695728],
              [113.902578, 22.695659],
              [113.901645, 22.695194],
              [113.901483, 22.694975],
              [113.900422, 22.695153],
              [113.901226, 22.695224],
              [113.902074, 22.696034],
              [113.902084, 22.696421],
              [113.90174, 22.696797],
              [113.902042, 22.697046],
              [113.902481, 22.696977],
              [113.902761, 22.697144],
              [113.903018, 22.69754],
              [113.903651, 22.697371],
              [113.903887, 22.697728],
              [113.904123, 22.697837],
              [113.90626, 22.700619],
              [113.905528, 22.70245],
              [113.905819, 22.704201],
              [113.906216, 22.704688],
              [113.906228, 22.705125],
              [113.911603, 22.705341],
              [113.912911, 22.706085],
              [113.913242, 22.706361],
              [113.913298, 22.707835],
              [113.913801, 22.709042],
              [113.913952, 22.709211],
              [113.914649, 22.70931],
              [113.915283, 22.709705],
              [113.916246, 22.71018],
              [113.916226, 22.709934],
              [113.91645, 22.709577],
              [113.916829, 22.709252],
              [113.917708, 22.70931],
              [113.918075, 22.709211],
              [113.919039, 22.709667],
              [113.919596, 22.709805],
              [113.920347, 22.70947],
              [113.920756, 22.709429],
              [113.921165, 22.709211],
              [113.921486, 22.70937],
              [113.922043, 22.709408],
              [113.923201, 22.70923],
              [113.923823, 22.70947],
              [113.924255, 22.709389],
              [113.924704, 22.709577],
              [113.925156, 22.709468],
              [113.925778, 22.708933],
              [113.92596, 22.708904],
              [113.92624, 22.70832],
              [113.927451, 22.706935],
              [113.927408, 22.706558],
              [113.927623, 22.705717],
              [113.927956, 22.705895],
              [113.928579, 22.706032],
              [113.929212, 22.706529],
              [113.929372, 22.707014],
              [113.929598, 22.707301],
              [113.930199, 22.707696],
              [113.930617, 22.707696],
              [113.931314, 22.708033],
              [113.931914, 22.707943],
              [113.932194, 22.708073],
              [113.933214, 22.707776],
              [113.933074, 22.707349],
              [113.933729, 22.706974],
              [113.934052, 22.706935],
              [113.9345, 22.706638],
              [113.93509, 22.7064],
              [113.935307, 22.705825],
              [113.935993, 22.705123],
              [113.936026, 22.704875],
              [113.936347, 22.704184],
              [113.936659, 22.704044],
              [113.937292, 22.7035],
              [113.937281, 22.703094],
              [113.937764, 22.702876],
              [113.938279, 22.702835],
              [113.938783, 22.703084],
              [113.93977, 22.703916],
              [113.940424, 22.704201],
              [113.940477, 22.704717],
              [113.940918, 22.70542],
              [113.941057, 22.705797],
              [113.940928, 22.70638],
              [113.940413, 22.706845],
              [113.938588, 22.708714],
              [113.940863, 22.708517],
              [113.942108, 22.709902],
              [113.94288, 22.71113],
              [113.946615, 22.711247],
              [113.947516, 22.712],
              [113.950521, 22.714059],
              [113.950734, 22.714375],
              [113.95112, 22.715287],
              [113.951593, 22.715841],
              [113.952151, 22.717067],
              [113.952495, 22.718176],
              [113.953138, 22.717463],
              [113.954683, 22.717899],
              [113.955756, 22.716948],
              [113.956572, 22.718849],
              [113.957945, 22.717977],
              [113.958201, 22.717226],
              [113.958589, 22.716948],
              [113.958761, 22.716672],
              [113.95876, 22.716038],
              [113.959576, 22.715642],
              [113.959919, 22.71489],
              [113.959876, 22.714337],
              [113.960348, 22.714099],
              [113.96069, 22.714059],
              [113.961249, 22.714178],
              [113.961206, 22.714613],
              [113.96155, 22.715128],
              [113.961636, 22.715563],
              [113.96198, 22.715603],
              [113.962751, 22.715444],
              [113.963223, 22.714772],
              [113.963738, 22.713743],
              [113.964339, 22.713228],
              [113.965026, 22.71299],
              [113.96567, 22.712674],
              [113.967, 22.712515],
              [113.967471, 22.712515],
              [113.967859, 22.712356],
              [113.968458, 22.711011],
              [113.969618, 22.710695],
              [113.970263, 22.710101],
              [113.971034, 22.710218],
              [113.971294, 22.710576],
              [113.971679, 22.710812],
              [113.972021, 22.711287],
              [113.97232, 22.711287],
              [113.972708, 22.711645],
              [113.973351, 22.711605],
              [113.973951, 22.711842],
              [113.974726, 22.711486],
              [113.975541, 22.711724],
              [113.976184, 22.71204],
              [113.976484, 22.712316],
              [113.977258, 22.712753],
              [113.97779, 22.713256],
              [113.978331, 22.713449],
              [113.978535, 22.713657],
              [113.978997, 22.713806],
              [113.979394, 22.714093],
              [113.979999, 22.71489],
              [113.980402, 22.715087],
              [113.980599, 22.715751],
              [113.980953, 22.716123],
              [113.981286, 22.716716],
              [113.981668, 22.716889],
              [113.982251, 22.716653],
              [113.982404, 22.716404],
              [113.982691, 22.71645],
              [113.983094, 22.716835],
              [113.98411, 22.71722],
              [113.984643, 22.718061],
              [113.985085, 22.718201],
              [113.985851, 22.718864],
              [113.986096, 22.719468],
              [113.986549, 22.719964],
              [113.986945, 22.720771],
              [113.987241, 22.721083],
              [113.987389, 22.72189],
              [113.987936, 22.722731],
              [113.988045, 22.723294],
              [113.988855, 22.723754],
              [113.989266, 22.723817],
              [113.990217, 22.724372],
              [113.990677, 22.724574],
              [113.990705, 22.72506],
              [113.991166, 22.72564],
              [113.99184, 22.725955],
              [113.992222, 22.726695],
              [113.992921, 22.726952],
              [113.993159, 22.727408],
              [113.993839, 22.728156],
              [113.994883, 22.728912],
              [113.995115, 22.729348],
              [113.995393, 22.729491],
              [113.995661, 22.729869],
              [113.996408, 22.730076],
              [113.996909, 22.730319],
              [113.997583, 22.731293],
              [113.998362, 22.731783],
              [113.998774, 22.732377],
              [113.999669, 22.733224],
              [114.000184, 22.733368],
              [114.000568, 22.733587],
              [114.00095, 22.733654],
              [114.001796, 22.734534],
              [114.002306, 22.734717],
              [114.003463, 22.736534],
              [114.004182, 22.736899],
              [114.005228, 22.737122],
              [114.00619, 22.736652],
              [114.006179, 22.735971],
              [114.008754, 22.735813],
              [114.008345, 22.736224],
              [114.008342, 22.73662],
              [114.008506, 22.738831],
              [114.009204, 22.739939],
              [114.00898, 22.741988],
              [114.008831, 22.742784],
              [114.008468, 22.743229],
              [114.008557, 22.74361],
              [114.008869, 22.744019],
              [114.007807, 22.744861],
              [114.008105, 22.745106],
              [114.007142, 22.745281],
              [114.006751, 22.746088],
              [114.006536, 22.74639],
              [114.006177, 22.746513],
              [114.004768, 22.747786],
              [114.003963, 22.74834],
              [114.003743, 22.748681],
              [114.006168, 22.750806],
              [114.005702, 22.751557],
              [114.00518, 22.75162],
              [114.004712, 22.751976],
              [114.004556, 22.751714],
              [114.004223, 22.751758],
              [114.004105, 22.751573],
              [114.004641, 22.75126],
              [114.004809, 22.750844],
              [114.004336, 22.750613],
              [114.004203, 22.750325],
              [114.002577, 22.751105],
              [114.002152, 22.751369],
              [114.000882, 22.751758],
              [114.000162, 22.752426],
              [113.999888, 22.753031],
              [113.999798, 22.753491],
              [113.99962, 22.75374],
              [113.998709, 22.753763],
              [113.997673, 22.754132],
              [113.997039, 22.75385],
              [113.996629, 22.753341],
              [113.995931, 22.753306],
              [113.994718, 22.753741],
              [113.993581, 22.753469],
              [113.992932, 22.753624],
              [113.992326, 22.753981],
              [113.992867, 22.754726],
              [113.993225, 22.755824],
              [113.993166, 22.756309],
              [113.992788, 22.757714],
              [113.992977, 22.75823],
              [113.993624, 22.759065],
              [113.994312, 22.758773],
              [113.994962, 22.758658],
              [113.995696, 22.758761],
              [113.996559, 22.758565],
              [113.99731, 22.759089],
              [113.99832, 22.76071],
              [113.998509, 22.76092],
              [113.999324, 22.761238],
              [113.99971, 22.76148],
              [114.000112, 22.762062],
              [114.000638, 22.762344],
              [114.001474, 22.762557],
              [114.002483, 22.762973],
              [114.002695, 22.763617],
              [114.002058, 22.764098],
              [114.001881, 22.764502],
              [114.001869, 22.765131],
              [114.001028, 22.766095],
              [114.000503, 22.767129],
              [114.000293, 22.767287],
              [113.999872, 22.767302],
              [113.998338, 22.76801],
              [113.997227, 22.768288],
              [113.996976, 22.768429],
              [113.9963, 22.768525],
              [113.996182, 22.768706],
              [113.995926, 22.769892],
              [113.995362, 22.770649],
              [113.995324, 22.771284],
              [113.995854, 22.771544],
              [113.996344, 22.772118],
              [113.997154, 22.7727],
              [113.998739, 22.774169],
              [113.998895, 22.774473],
              [113.998877, 22.774824],
              [113.998433, 22.776553],
              [113.997634, 22.776685],
              [113.996874, 22.777165],
              [113.996691, 22.778184],
              [113.996161, 22.778722],
              [113.995832, 22.779201],
              [113.995422, 22.780388],
              [113.994153, 22.78244],
              [113.993976, 22.783087],
              [113.99394, 22.784456],
              [113.992508, 22.787829],
              [113.992579, 22.788371],
              [113.992871, 22.788965],
              [113.992683, 22.789941],
              [113.992176, 22.79054],
              [113.991957, 22.791033],
              [113.991743, 22.791889],
              [113.991451, 22.792451],
              [113.990961, 22.794045],
              [113.991168, 22.795598],
              [113.990877, 22.798909],
              [113.991041, 22.800116],
              [113.990861, 22.800207],
              [113.984466, 22.800293],
              [113.982493, 22.799892],
              [113.980923, 22.799733],
              [113.980705, 22.799631],
              [113.980581, 22.800049],
              [113.980791, 22.800559],
              [113.981127, 22.800883],
              [113.982237, 22.800818],
              [113.983324, 22.800996],
              [113.983807, 22.800705],
              [113.984096, 22.800752],
              [113.984467, 22.802184],
              [113.984596, 22.803555],
              [113.984358, 22.803754],
              [113.984146, 22.803633],
              [113.983485, 22.802878],
              [113.982525, 22.802743],
              [113.98202, 22.802005],
              [113.979942, 22.800821],
              [113.97922, 22.800687],
              [113.978853, 22.801285],
              [113.978529, 22.801335],
              [113.978402, 22.800918],
              [113.978679, 22.80022],
              [113.978661, 22.800026],
              [113.977843, 22.799121],
              [113.977521, 22.798956],
              [113.97725, 22.799085],
              [113.977198, 22.799375],
              [113.977329, 22.800061],
              [113.977753, 22.800642],
              [113.977766, 22.800793],
              [113.976874, 22.800612],
              [113.976817, 22.800311],
              [113.976417, 22.80016],
              [113.97627, 22.800258],
              [113.975975, 22.801557],
              [113.975827, 22.801656],
              [113.975103, 22.801661],
              [113.974923, 22.801376],
              [113.975757, 22.799216],
              [113.975766, 22.798343],
              [113.97517, 22.79766],
              [113.974788, 22.797806],
              [113.974996, 22.798437],
              [113.973126, 22.80028],
              [113.972387, 22.801776],
              [113.972266, 22.802256],
              [113.972725, 22.803826],
              [113.973533, 22.804937],
              [113.974202, 22.805439],
              [113.974843, 22.80561],
              [113.975827, 22.80558],
              [113.976174, 22.805661],
              [113.978402, 22.806512],
              [113.977176, 22.80737],
              [113.977033, 22.807893],
              [113.976974, 22.809098],
              [113.9766, 22.809846],
              [113.976373, 22.810081],
              [113.975724, 22.810416],
              [113.974202, 22.81057],
              [113.973739, 22.810722],
              [113.973444, 22.811068],
              [113.97287, 22.812078],
              [113.972348, 22.812498],
              [113.97122, 22.812436],
              [113.970057, 22.812906],
              [113.969465, 22.812986],
              [113.969117, 22.812887],
              [113.968569, 22.812179],
              [113.968169, 22.812057],
              [113.967258, 22.812095],
              [113.966104, 22.81243],
              [113.964867, 22.813415],
              [113.964772, 22.814204],
              [113.965146, 22.814725],
              [113.965173, 22.814912],
              [113.964763, 22.815843],
              [113.964319, 22.815641],
              [113.963094, 22.814609],
              [113.961394, 22.813368],
              [113.960549, 22.81313],
              [113.959066, 22.813409],
              [113.958898, 22.813634],
              [113.958892, 22.814254],
              [113.958212, 22.814614],
              [113.957352, 22.814675],
              [113.957135, 22.81444],
              [113.95697, 22.814005],
              [113.956519, 22.814314],
              [113.954979, 22.815053],
              [113.954945, 22.81589],
              [113.955217, 22.816158],
              [113.955426, 22.816774],
              [113.954677, 22.81676],
              [113.954477, 22.818491],
              [113.95558, 22.819641],
              [113.955259, 22.820331],
              [113.954651, 22.82103],
              [113.952589, 22.822191],
              [113.950504, 22.822705],
              [113.950219, 22.823069],
              [113.949247, 22.823664],
              [113.948029, 22.825157],
              [113.94788, 22.826863],
              [113.947594, 22.827183],
              [113.946899, 22.827488],
              [113.944095, 22.827696],
              [113.943749, 22.827875],
              [113.943513, 22.828267],
              [113.942769, 22.828816],
              [113.941989, 22.828931],
              [113.941279, 22.828808],
              [113.939762, 22.829301],
              [113.939573, 22.829569],
              [113.939286, 22.830518],
              [113.939167, 22.830678],
              [113.938015, 22.830876],
              [113.937367, 22.831113],
              [113.937611, 22.831486],
              [113.937823, 22.832713],
              [113.937684, 22.832807],
              [113.936692, 22.832533],
              [113.935134, 22.832451],
              [113.931289, 22.831922],
              [113.929489, 22.83201],
              [113.928114, 22.831739],
              [113.92738, 22.831368],
              [113.925299, 22.830869],
              [113.924523, 22.830579],
              [113.92281, 22.830956],
              [113.921893, 22.831248],
              [113.920652, 22.831312],
              [113.918099, 22.830728],
              [113.916764, 22.83025],
              [113.916447, 22.83004],
              [113.915833, 22.829241],
              [113.915536, 22.829034],
              [113.914676, 22.829685],
              [113.914279, 22.830108],
              [113.912523, 22.830177],
              [113.910959, 22.829995]
            ]
          ]
        ]
      }
    }]
  });
}));
